@@ -4,7 +4,7 @@ package WebService::OpenSky;
 
 # ABSTRACT: Perl interface to the OpenSky Network API
 
-our $VERSION = '0.009';
+our $VERSION = '0.1';
 use v5.20.0;
 use Moose;
 use WebService::OpenSky::Types qw(
@@ -405,7 +405,7 @@ WebService::OpenSky - Perl interface to the OpenSky Network API
 
 =head1 VERSION
 
-version 0.009
+version 0.1
 
 =head1 SYNOPSIS
 
@@ -638,11 +638,14 @@ Identical to C<get_arrivals_by_airport>, but returns departures instead of arriv
 
 =head2 C<get_flights_by_aircraft>
 
-    my $flights = $api->get_flights_by_aircraft('abc9f3', $start, $end);
+    my $flights = $api->get_flights_by_aircraft($icao24, $start, $end);
 
 Returns an instance of L<WebService::OpenSky::Response::Flights>.
 
-The first argument is the ICAO24 transponder address of the aircraft you want.
+The first argument is the lower-case ICAO24 transponder address of the aircraft you want.
+
+The second and third arguments are the start and end times in seconds since
+epoch (Unix timestamp). Their interval must be equal to or less than 30 days.
 
 =head2 C<get_flights_from_interval>
 
@@ -722,9 +725,9 @@ following code ...
     my $musks_jet = 'a835af';
     my $openapi   = WebService::OpenSky->new;
 
-    my $days = 7;
+    my $days = shift @ARGV // 7;
     my $now  = time;
-    my $then = $now - 86400 * 7;    # up to 7 days ago
+    my $then = $now - 86400 * $days;    # Max 30 days
 
     my $flight_data = $openapi->get_flights_by_aircraft( $musks_jet, $then, $now );
     say "Jet $musks_jet has " . $flight_data->count . " flights";
@@ -746,14 +749,6 @@ by the aviation industry, while others have used this public data to predict
 corporate mergers and acquisitions. There are a wealth of reasons why this
 data is useful, but not all of those reasons are good. Be good.
 
-=head1 TODO
-
-=over 4
-
-=item * Add Waypoints and Flight Routes
-
-=back
-
 =head1 AUTHOR
 
 Curtis "Ovid" Poe <curtis.poe@gmail.com>
